@@ -38,7 +38,6 @@
 #include <gio/gio.h>
 #include <libpeas-gtk/peas-gtk-plugin-manager.h>
 
-#define GSETTINGS_OBJECT_KEY		"GSETTINGS_KEY"
 #define GSETTINGS_OBJECT_VALUE		"GSETTINGS_VALUE"
 
 struct _EomPreferencesDialogPrivate {
@@ -46,6 +45,7 @@ struct _EomPreferencesDialogPrivate {
 	GSettings    *ui_settings;
 	GSettings    *fullscreen_settings;
 
+	GtkWidget     *notebook;
 	GtkWidget     *interpolate_check;
 	GtkWidget     *extrapolate_check;
 	GtkWidget     *autorotate_check;
@@ -151,6 +151,9 @@ eom_preferences_dialog_class_init (EomPreferencesDialogClass *klass)
 
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/mate/eom/ui/eom-preferences-dialog.ui");
+	gtk_widget_class_bind_template_child_private (widget_class,
+	                                              EomPreferencesDialog,
+	                                              notebook);
 	gtk_widget_class_bind_template_child_private (widget_class,
 	                                              EomPreferencesDialog,
 	                                              interpolate_check);
@@ -210,8 +213,7 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	priv->view_settings = g_settings_new (EOM_CONF_VIEW);
 	priv->fullscreen_settings = g_settings_new (EOM_CONF_FULLSCREEN);
 
-	g_signal_connect (G_OBJECT (pref_dlg),
-	                  "response",
+	g_signal_connect (pref_dlg, "response",
 	                  G_CALLBACK (eom_preferences_response_cb),
 	                  pref_dlg);
 
@@ -243,8 +245,7 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	                   GSETTINGS_OBJECT_VALUE,
 	                   GINT_TO_POINTER (EOM_TRANSP_COLOR));
 
-	g_signal_connect (G_OBJECT (priv->color_radio),
-	                  "toggled",
+	g_signal_connect (priv->color_radio, "toggled",
 	                  G_CALLBACK (pd_transp_radio_toggle_cb),
 	                  priv->view_settings);
 
@@ -252,8 +253,7 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	                   GSETTINGS_OBJECT_VALUE,
 	                   GINT_TO_POINTER (EOM_TRANSP_CHECKED));
 
-	g_signal_connect (G_OBJECT (priv->checkpattern_radio),
-	                  "toggled",
+	g_signal_connect (priv->checkpattern_radio, "toggled",
 	                  G_CALLBACK (pd_transp_radio_toggle_cb),
 	                  priv->view_settings);
 
@@ -261,8 +261,7 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	                   GSETTINGS_OBJECT_VALUE,
 	                   GINT_TO_POINTER (EOM_TRANSP_BACKGROUND));
 
-	g_signal_connect (G_OBJECT (priv->background_radio),
-	                  "toggled",
+	g_signal_connect (priv->background_radio, "toggled",
 	                  G_CALLBACK (pd_transp_radio_toggle_cb),
 	                  priv->view_settings);
 
@@ -304,8 +303,7 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	                 EOM_CONF_FULLSCREEN_RANDOM,
 	                 priv->random_check, "active",
 	                 G_SETTINGS_BIND_DEFAULT);
-	g_signal_connect (priv->fullscreen_settings,
-	                  "changed::" EOM_CONF_FULLSCREEN_RANDOM,
+	g_signal_connect (priv->fullscreen_settings, "changed::" EOM_CONF_FULLSCREEN_RANDOM,
 	                  G_CALLBACK (random_change_cb),
 	                  priv->loop_check);
 	random_change_cb (priv->fullscreen_settings,
@@ -318,6 +316,12 @@ eom_preferences_dialog_init (EomPreferencesDialog *pref_dlg)
 	                 G_SETTINGS_BIND_DEFAULT);
 
 	gtk_widget_show_all (priv->plugin_manager);
+
+    /* Add tab scrolling support for GTK3 */
+    gtk_widget_add_events (priv->notebook, GDK_SCROLL_MASK);
+    g_signal_connect (priv->notebook, "scroll-event",
+                      G_CALLBACK (eom_notebook_scroll_event_cb),
+                      NULL);
 }
 
 GtkWidget *eom_preferences_dialog_get_instance (GtkWindow *parent)
