@@ -46,8 +46,6 @@
 #include <exempi/xmp.h>
 #endif
 
-#define EOM_CSS_FILE_PATH EOM_DATA_DIR G_DIR_SEPARATOR_S "eom.css"
-
 static EomStartupFlags flags;
 
 static gboolean fullscreen = FALSE;
@@ -99,9 +97,11 @@ main (int argc, char **argv)
 	GFile *css_file;
 	GtkCssProvider *provider;
 
+#ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, EOM_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	gdk_set_allowed_backends ("wayland,x11");
 
